@@ -26,7 +26,7 @@ from .search import rpn_contraints, query_from_xml
 from .errors import is_xnat_error, parse_put_error_message
 from .errors import DataError, ProgrammingError, catch_error
 from .provenance import Provenance
-# from .pipelines import Pipelines
+from .pipelines import Pipelines
 from . import schema
 from . import httputil
 from . import downloadutils
@@ -955,8 +955,7 @@ class CObject(object):
         else:
             raise ProgrammingError('One in [contraints, template and '
                                    'query] parameters must be correctly '
-                                   'set.'
-                                   )
+                                   'set.')
 
         # _columns = [
         #     'xnat:subjectData/PROJECT',
@@ -1034,7 +1033,7 @@ class Project(EObject):
         """
 
         EObject.__init__(self, uri, interface)
-        # self.pipelines = Pipelines(self.id(), self._intf)
+        self.pipelines = Pipelines(self, self._intf)
 
     def __repr__(self):
         interface = self._intf
@@ -1334,8 +1333,7 @@ class Project(EObject):
 
                     group_element = lxml.etree.Element(
                         lxml.etree.QName(tree.nsmap['xnat'], 'definition'),
-                        nsmap=tree.nsmap
-                        )
+                        nsmap=tree.nsmap)
                     group_element.set('ID', group)
                     group_element.set(
                         'data-type', protocol_element.get('data-type'))
@@ -1344,8 +1342,7 @@ class Project(EObject):
                     definitions_element.append(group_element)
                     fields_element = lxml.etree.Element(
                         lxml.etree.QName(tree.nsmap['xnat'], 'fields'),
-                        nsmap=tree.nsmap
-                        )
+                        nsmap=tree.nsmap)
                     group_element.append(fields_element)
 
                 for field, datatype in fields.items():
@@ -1365,8 +1362,7 @@ class Project(EObject):
                             'xmlPath',
                             "xnat:%s/fields/field[name=%s]/field" % (
                                 protocol_element.get(
-                                    'data-type').split(':')[-1], field)
-                            )
+                                    'data-type').split(':')[-1], field))
                         fields_element.append(field_element)
                         update = True
         if update:
@@ -1374,8 +1370,7 @@ class Project(EObject):
                 lxml.etree.tostring(tree).decode('utf-8'),
                 'text/xml',
                 'cust.xml',
-                'cust.xml'
-                )
+                'cust.xml')
 
             uri = self._uri
             if allow_data_deletion:
@@ -1520,24 +1515,52 @@ class Subject(EObject):
         return Projects(join_uri(self._uri, 'projects'),
                         self._intf, id_filter)
 
-    def share(self, project):
-        """ Share this subject with another project.
+    def share(self, project, label=None, primary=False):
+        """ Share the subject with another project.
 
             Parameters
             ----------
                 project: string
-                    The other project name.
+                    Target project name.
+                label: string
+                    Subject label as shared resource. By default, the original
+                    subject label is used.
+                primary: boolean
+                    If True, the ownership of the subject will be transferred to
+                    the target project. User must be owner of both projects to
+                    perform this operation.
         """
-        self._intf._exec(join_uri(self._uri, 'projects', project), 'PUT')
+        owner_project = self.attrs.get('project')
+        aliases = self._intf.select.project(owner_project).aliases()
+        if project in [owner_project] + aliases:
+            raise ValueError("Cannot share a subject with its owner project.")
+
+        options = []
+        if label:
+            options.append('label=%s' % label)
+        else:
+            options.append('label=%s' % self.label())
+        if primary:
+            options.append('primary=true')
+
+        options = '?' + '&'.join(options)
+
+        self._intf._exec(join_uri(self._uri, 'projects', project) + options, 'PUT')
 
     def unshare(self, project):
-        """ Remove subject from another project in which it was shared.
+        """ Unlink subject from a project it was shared with. Subject cannot be
+            unshared from the project that owns it.
 
             Parameters
             ----------
                 project: string
-                    The other project name.
+                    Target project name.
         """
+        owner_project = self.attrs.get('project')
+        aliases = self._intf.select.project(owner_project).aliases()
+        if project in [owner_project] + aliases:
+            raise ValueError("Cannot unlink a subject from its owner project.")
+
         self._intf._exec(join_uri(self._uri, 'projects', project), 'DELETE')
 
 
@@ -1625,24 +1648,52 @@ class Experiment(EObject):
         return Projects(join_uri(self._uri, 'projects'),
                         self._intf, id_filter)
 
-    def share(self, project):
-        """ Share this experiment with another project.
+    def share(self, project, label=None, primary=False):
+        """ Share the experiment with another project.
 
             Parameters
             ----------
                 project: string
-                    The other project name.
+                    Target project name.
+                label: string
+                    Experiment label as shared resource. By default, the original
+                    experiment label is used.
+                primary: boolean
+                    If True, the ownership of the subject will be transferred to
+                    the target project. User must be owner of both projects to
+                    perform this operation.
         """
-        self._intf._exec(join_uri(self._uri, 'projects', project), 'PUT')
+        owner_project = self.attrs.get('project')
+        aliases = self._intf.select.project(owner_project).aliases()
+        if project in [owner_project] + aliases:
+            raise ValueError("Cannot share an experiment with its owner project.")
+
+        options = []
+        if label:
+            options.append('label=%s' % label)
+        else:
+            options.append('label=%s' % self.label())
+        if primary:
+            options.append('primary=true')
+
+        options = '?' + '&'.join(options)
+
+        self._intf._exec(join_uri(self._uri, 'projects', project) + options, 'PUT')
 
     def unshare(self, project):
-        """ Remove experiment from another project in which it was shared.
+        """ Unlink experiment from a project it was shared with. Experiment cannot
+            be unshared from the project that owns it.
 
             Parameters
             ----------
                 project: string
-                    The other project name.
+                    Target project name.
         """
+        owner_project = self.attrs.get('project')
+        aliases = self._intf.select.project(owner_project).aliases()
+        if project in [owner_project] + aliases:
+            raise ValueError("Cannot unlink an experiment from its owner project.")
+
         self._intf._exec(join_uri(self._uri, 'projects', project), 'DELETE')
 
     def trigger_pipelines(self):
@@ -1695,36 +1746,6 @@ class Assessor(EObject):
 
         self.provenance = Provenance(self)
 
-    def shares(self, id_filter='*'):
-        """ Returns the projects sharing this assessor.
-
-            Returns
-            -------
-            Collection object.
-        """
-        return Projects(join_uri(self._uri, 'projects'),
-                        self._intf, id_filter)
-
-    def share(self, project):
-        """ Share this assessor with another project.
-
-            Parameters
-            ----------
-                project: string
-                    The other project name.
-        """
-        self._intf._exec(join_uri(self._uri, 'projects', project), 'PUT')
-
-    def unshare(self, project):
-        """ Remove assessor from another project in which it was shared.
-
-            Parameters
-            ----------
-                project: string
-                    The other project name.
-        """
-        self._intf._exec(join_uri(self._uri, 'projects', project), 'DELETE')
-
     def set_param(self, key, value):
         self.attrs.set('%s/parameters/addParam[name=%s]/addField'
                        % (self.datatype(), key),
@@ -2401,21 +2422,6 @@ class Experiments(CObject):
 @add_metaclass(CollectionType)
 class Assessors(CObject):
 
-    def sharing(self, projects=[]):
-        return Assessors([eobj for eobj in self
-                          if set(projects).issubset(eobj.shares().get())
-                          ],
-                         self._intf
-                         )
-
-    def share(self, project):
-        for eobj in self:
-            eobj.share(project)
-
-    def unshare(self, project):
-        for eobj in self:
-            eobj.unshare(project)
-
     def download(self, dest_dir, type="ALL",
                  name=None, extract=False, safe=False, removeZip=False):
         """
