@@ -6,6 +6,9 @@ except ImportError:
     from io import StringIO
 try:
     unicode
+    import sys
+    reload(sys)  # Reload does the trick!
+    sys.setdefaultencoding('UTF8')
 except NameError:
     unicode = str
 from six import string_types
@@ -16,12 +19,11 @@ from .jsonutil import JsonTable, get_column, get_where, get_selection
 from .errors import is_xnat_error, catch_error
 from .errors import ProgrammingError, NotSupportedError
 from .errors import DataError, DatabaseError
-from .uriutil import check_entry
 
-search_nsmap = {'xdat':'http://nrg.wustl.edu/security',
-                'xsi':'http://www.w3.org/2001/XMLSchema-instance'}
+search_nsmap = {'xdat': 'http://nrg.wustl.edu/security',
+                'xsi': 'http://www.w3.org/2001/XMLSchema-instance'}
 
-special_ops = {'*':'%', }
+special_ops = {'*': '%', }
 
 
 def build_search_document(root_element_name, columns, criteria_set,
@@ -124,6 +126,7 @@ def build_search_document(root_element_name, columns, criteria_set,
 
     return etree.tostring(root_node.getroottree())
 
+
 def build_criteria_set(container_node, criteria_set):
 
     for criteria in criteria_set:
@@ -142,8 +145,7 @@ def build_criteria_set(container_node, criteria_set):
         if isinstance(criteria, (tuple)):
             if len(criteria) != 3:
                 raise ProgrammingError('%s should be a 3-element tuple' %
-                                        str(criteria)
-                                        )
+                                       str(criteria))
 
             constraint_node = \
                 etree.Element(etree.QName(search_nsmap['xdat'], 'criteria'),
@@ -186,6 +188,7 @@ def build_criteria_set(container_node, criteria_set):
 
     return container_node
 
+
 def query_from_xml(document):
     query = {}
     root = etree.fromstring(document)
@@ -218,11 +221,12 @@ def query_from_xml(document):
                                   namespaces=root.nsmap)[0]
 
         query['constraints'] = query_from_criteria_set(search_where)
-    except:
+    except Exception:
         query['constraints'] = [('%s/ID' % query['row'], 'LIKE', '%'), 'AND']
 
     return query
 
+
 def query_from_criteria_set(criteria_set):
     query = []
     query.append(criteria_set.get('method'))
@@ -245,6 +249,7 @@ def query_from_criteria_set(criteria_set):
 
     return query
 
+
 def rpn_contraints(rpn_exp):
     left = []
     right = []
@@ -255,7 +260,7 @@ def rpn_contraints(rpn_exp):
             if 'AND' in right or 'OR' in right and left == []:
                 try:
                     operator = right.pop(right.index('AND'))
-                except:
+                except Exception:
                     operator = right.pop(right.index('OR'))
 
                 left = [right[0]]
@@ -291,6 +296,7 @@ def rpn_contraints(rpn_exp):
 
 # ---------------------------------------------------------------
 
+
 class SearchManager(object):
     """ Search interface.
         Handles operations to save and get back searches on the server.
@@ -366,7 +372,6 @@ class SearchManager(object):
         self._save_search(row, columns, constraints,
                           name, description, sharing)
 
-
     def saved(self, with_description=False):
         """ Returns the names of accessible saved search on the server.
         """
@@ -424,12 +429,12 @@ class SearchManager(object):
             else:
                 return query_from_xml(bundle)
 
-
         content = self._intf._exec(
             '%s/search/saved/%s/results?format=csv' % (self._intf._entry,
                                                        search_id), 'GET')
 
-        results = csv.reader(StringIO(content.decode('utf-8')), delimiter=',', quotechar='"')
+        results = csv.reader(StringIO(content.decode('utf-8')), delimiter=',',
+                             quotechar='"')
 
         headers = next(results)
 
@@ -476,7 +481,8 @@ class SearchManager(object):
                 List of data fields from
                 `Interface.inspect.datatypes('*', '*')`
             constraints: list
-                See also: `Search.where()`, values are keywords for the template
+                See also: `Search.where()`, values are keywords for the
+                template
             sharing: string | list
                 Define by whom the query is visible.
                 If sharing is a string it may be either
@@ -485,7 +491,6 @@ class SearchManager(object):
                 from `Interface.users()`.
         """
 
-
         def _make_template(query):
             query_template = []
 
@@ -612,7 +617,8 @@ class SearchManager(object):
             return bundle
         else:
             _query = query_from_xml(bundle)
-            return _query['row'], _query['columns'], _query['constraints'], _query['description']
+            return (_query['row'], _query['columns'], _query['constraints'],
+                    _query['description'])
 
     def delete_template(self, name):
         """ Deletes a search template.
@@ -708,7 +714,8 @@ class Search(object):
         if is_xnat_error(content):
             catch_error(content)
 
-        results = csv.reader(StringIO(content.decode('utf-8')), delimiter=',', quotechar='"')
+        results = csv.reader(StringIO(content.decode('utf-8')), delimiter=',',
+                             quotechar='"')
         headers = next(results)
 
         headers_of_interest = []
@@ -717,8 +724,8 @@ class Search(object):
             try:
                 headers_of_interest.append(
                     difflib.get_close_matches(
-                        column.split(self._row + '/')[0].lower() \
-                            or column.split(self._row + '/')[1].lower(),
+                        column.split(self._row + '/')[0].lower()
+                        or column.split(self._row + '/')[1].lower(),
                         headers)[0]
                     )
             except IndexError:
